from django.utils.translation import ugettext as _

GEOWARE_CURRENCY_DATA = {
    "AED": {
        "code": "AED",
        "fractional_ratio": 100,
        "fractional_unit": "Fils",
        "name": "Dirham (United Arab Emirates)",
        "symbol": "د.إ"
    },
    "AFN": {
        "code": "AFN",
        "fractional_ratio": 100,
        "fractional_unit": "Pul",
        "name": "Afghani (Afghanistan)",
        "symbol": "؋"
    },
    "ALL": {
        "code": "ALL",
        "fractional_ratio": 100,
        "fractional_unit": "Qindarkë",
        "name": "Lek (Albania)",
        "symbol": "L"
    },
    "AMD": {
        "code": "AMD",
        "fractional_ratio": 100,
        "fractional_unit": "Luma",
        "name": "Dram (Armenia)",
        "symbol": "դր."
    },
    "ANG": {
        "code": "ANG",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Antilles Guilder (Netherlands)",
        "symbol": "ƒ"
    },
    "AOA": {
        "code": "AOA",
        "fractional_ratio": 100,
        "fractional_unit": "Cêntimo",
        "name": "Kwanza (Angola)",
        "symbol": "Kz"
    },
    "AQD": {
        "code": "AQD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Antarctica)",
        "symbol": "$"
    },
    "ARS": {
        "code": "ARS",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Argentina)",
        "symbol": "$"
    },
    "AUD": {
        "code": "AUD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Australia)",
        "symbol": "$"
    },
    "AWG": {
        "code": "AWG",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Guilder (Aruba)",
        "symbol": "ƒ"
    },
    "AZN": {
        "code": "AZN",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "New Manat (Azerbaijan)",
        "symbol": ""
    },
    "BAM": {
        "code": "BAM",
        "fractional_ratio": 100,
        "fractional_unit": "Fening",
        "name": "Convertible Marka (Bosnia and Herzegovina)",
        "symbol": "KM"
    },
    "BBD": {
        "code": "BBD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Barbados)",
        "symbol": "$"
    },
    "BDT": {
        "code": "BDT",
        "fractional_ratio": 100,
        "fractional_unit": "Paisa",
        "name": "Taka (Bangladesh)",
        "symbol": "৳"
    },
    "BGN": {
        "code": "BGN",
        "fractional_ratio": 100,
        "fractional_unit": "Stotinka",
        "name": "Lev (Bulgaria)",
        "symbol": "лв"
    },
    "BHD": {
        "code": "BHD",
        "fractional_ratio": 1000,
        "fractional_unit": "Fils",
        "name": "Dinar (Bahrain)",
        "symbol": ".د.ب"
    },
    "BIF": {
        "code": "BIF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Burundi)",
        "symbol": "Fr"
    },
    "BMD": {
        "code": "BMD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Bermuda)",
        "symbol": "$"
    },
    "BND": {
        "code": "BND",
        "fractional_ratio": 100,
        "fractional_unit": "Sen",
        "name": "Darussalam Dollar (Brunei)",
        "symbol": "$"
    },
    "BOB": {
        "code": "BOB",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Boliviano (Bolivia)",
        "symbol": "Bs."
    },
    "BRL": {
        "code": "BRL",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Real (Brazil)",
        "symbol": "R$"
    },
    "BSD": {
        "code": "BSD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Bahamas)",
        "symbol": "$"
    },
    "BTN": {
        "code": "BTN",
        "fractional_ratio": 100,
        "fractional_unit": "Chetrum",
        "name": "Ngultrum (Bhutan)",
        "symbol": "Nu."
    },
    "BWP": {
        "code": "BWP",
        "fractional_ratio": 100,
        "fractional_unit": "Thebe",
        "name": "Pula (Botswana)",
        "symbol": "P"
    },
    "BYR": {
        "code": "BYR",
        "fractional_ratio": 100,
        "fractional_unit": "Kapyeyka",
        "name": "Ruble (Belarus)",
        "symbol": "Br"
    },
    "BZD": {
        "code": "BZD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Belize)",
        "symbol": "$"
    },
    "CAD": {
        "code": "CAD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Canada)",
        "symbol": "$"
    },
    "CDF": {
        "code": "CDF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Congo/Kinshasa)",
        "symbol": "Fr"
    },
    "CHF": {
        "code": "CHF",
        "fractional_ratio": 100,
        "fractional_unit": "Rappen",
        "name": "Franc (Switzerland)",
        "symbol": "Fr"
    },
    "CLP": {
        "code": "CLP",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Chile)",
        "symbol": "$"
    },
    "CNY": {
        "code": "CNY",
        "fractional_ratio": 100,
        "fractional_unit": "Fen",
        "name": "Yuan Renminbi (China)",
        "symbol": "¥"
    },
    "COP": {
        "code": "COP",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Colombia)",
        "symbol": "$"
    },
    "CRC": {
        "code": "CRC",
        "fractional_ratio": 100,
        "fractional_unit": "Céntimo",
        "name": "Colon (Costa Rica)",
        "symbol": "₡"
    },
    "CUC": {
        "code": "CUC",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Convertible Peso (Cuba)",
        "symbol": "$"
    },
    "CUP": {
        "code": "CUP",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Peso (Cuba)",
        "symbol": ""
    },
    "CVE": {
        "code": "CVE",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Escudo (Cape Verde)",
        "symbol": "$"
    },
    "CZK": {
        "code": "CZK",
        "fractional_ratio": 100,
        "fractional_unit": "Haléř",
        "name": "Koruna (Czech Republic)",
        "symbol": "Kč"
    },
    "DJF": {
        "code": "DJF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Djibouti)",
        "symbol": "Fr"
    },
    "DKK": {
        "code": "DKK",
        "fractional_ratio": 100,
        "fractional_unit": "Øre",
        "name": "Krone (Denmark)",
        "symbol": "kr"
    },
    "DOP": {
        "code": "DOP",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Dominican Republic)",
        "symbol": "$"
    },
    "DZD": {
        "code": "DZD",
        "fractional_ratio": 100,
        "fractional_unit": "Santeem",
        "name": "Dinar (Algeria)",
        "symbol": "د.ج"
    },
    "EGP": {
        "code": "EGP",
        "fractional_ratio": 100,
        "fractional_unit": "Piastre",
        "name": "Pound (Egypt)",
        "symbol": "£"
    },
    "ERN": {
        "code": "ERN",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Nakfa (Eritrea)",
        "symbol": "Nfk"
    },
    "ETB": {
        "code": "ETB",
        "fractional_ratio": 100,
        "fractional_unit": "Santim",
        "name": "Birr (Ethiopia)",
        "symbol": "Br"
    },
    "EUR": {
        "code": "EUR",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Euro (European Union Countries)",
        "symbol": "€"
    },
    "FJD": {
        "code": "FJD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Fiji)",
        "symbol": "$"
    },
    "FKP": {
        "code": "FKP",
        "fractional_ratio": 100,
        "fractional_unit": "Penny",
        "name": "Malvinas Pound (Falkland Islands)",
        "symbol": "£"
    },
    "GBP": {
        "code": "GBP",
        "fractional_ratio": 100,
        "fractional_unit": "Penny",
        "name": "Pound (United Kingdom)",
        "symbol": "£"
    },
    "GEL": {
        "code": "GEL",
        "fractional_ratio": 100,
        "fractional_unit": "Tetri",
        "name": "Lari (Georgia)",
        "symbol": "ლ"
    },
    "GGP": {
        "code": "GGP",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Pound (Guernsey)",
        "symbol": ""
    },
    "GHS": {
        "code": "GHS",
        "fractional_ratio": 100,
        "fractional_unit": "Pesewa",
        "name": "Cedi (Ghana)",
        "symbol": "₵"
    },
    "GIP": {
        "code": "GIP",
        "fractional_ratio": 100,
        "fractional_unit": "Penny",
        "name": "Pound (Gibraltar)",
        "symbol": "£"
    },
    "GMD": {
        "code": "GMD",
        "fractional_ratio": 100,
        "fractional_unit": "Butut",
        "name": "Dalasi (Gambia)",
        "symbol": "D"
    },
    "GNF": {
        "code": "GNF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Guinea)",
        "symbol": "Fr"
    },
    "GTQ": {
        "code": "GTQ",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Quetzal (Guatemala)",
        "symbol": "Q"
    },
    "GYD": {
        "code": "GYD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Guyana)",
        "symbol": "$"
    },
    "HKD": {
        "code": "HKD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Hong Kong)",
        "symbol": "$"
    },
    "HNL": {
        "code": "HNL",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Lempira (Honduras)",
        "symbol": "L"
    },
    "HRK": {
        "code": "HRK",
        "fractional_ratio": 100,
        "fractional_unit": "Lipa",
        "name": "Kuna (Croatia)",
        "symbol": "kn"
    },
    "HTG": {
        "code": "HTG",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Gourde (Haiti)",
        "symbol": "G"
    },
    "HUF": {
        "code": "HUF",
        "fractional_ratio": 100,
        "fractional_unit": "Fillér",
        "name": "Forint (Hungary)",
        "symbol": "Ft"
    },
    "IDR": {
        "code": "IDR",
        "fractional_ratio": 100,
        "fractional_unit": "Sen",
        "name": "Rupiah (Indonesia)",
        "symbol": "Rp"
    },
    "ILS": {
        "code": "ILS",
        "fractional_ratio": 100,
        "fractional_unit": "Agora",
        "name": "Shekel (Israel)",
        "symbol": "₪"
    },
    "IMP": {
        "code": "IMP",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Pound (Isle of Man)",
        "symbol": ""
    },
    "INR": {
        "code": "INR",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Rupee (India)",
        "symbol": ""
    },
    "IQD": {
        "code": "IQD",
        "fractional_ratio": 1000,
        "fractional_unit": "Fils",
        "name": "Dinar (Iraq)",
        "symbol": "ع.د"
    },
    "IRR": {
        "code": "IRR",
        "fractional_ratio": 1,
        "fractional_unit": "Rial",
        "name": "Rial (Iran)",
        "symbol": "﷼"
    },
    "ISK": {
        "code": "ISK",
        "fractional_ratio": 100,
        "fractional_unit": "Eyrir",
        "name": "Krona (Iceland)",
        "symbol": "kr"
    },
    "JEP": {
        "code": "JEP",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Pound (Jersey)",
        "symbol": ""
    },
    "JMD": {
        "code": "JMD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Jamaica)",
        "symbol": "$"
    },
    "JOD": {
        "code": "JOD",
        "fractional_ratio": 100,
        "fractional_unit": "Piastre",
        "name": "Dinar (Jordan)",
        "symbol": "د.ا"
    },
    "JPY": {
        "code": "JPY",
        "fractional_ratio": 100,
        "fractional_unit": "Sen",
        "name": "Yen (Japan)",
        "symbol": "¥"
    },
    "KES": {
        "code": "KES",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Shilling (Kenya)",
        "symbol": "Sh"
    },
    "KGS": {
        "code": "KGS",
        "fractional_ratio": 100,
        "fractional_unit": "Tyiyn",
        "name": "Som (Kyrgyzstan)",
        "symbol": "лв"
    },
    "KHR": {
        "code": "KHR",
        "fractional_ratio": 100,
        "fractional_unit": "Sen",
        "name": "Riel (Cambodia)",
        "symbol": "៛"
    },
    "KMF": {
        "code": "KMF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Comoros)",
        "symbol": "Fr"
    },
    "KPW": {
        "code": "KPW",
        "fractional_ratio": 100,
        "fractional_unit": "Chon",
        "name": "Won (North Korea)",
        "symbol": "₩"
    },
    "KRW": {
        "code": "KRW",
        "fractional_ratio": 100,
        "fractional_unit": "Jeon",
        "name": "Won (South Korea)",
        "symbol": "₩"
    },
    "KWD": {
        "code": "KWD",
        "fractional_ratio": 1000,
        "fractional_unit": "Fils",
        "name": "Dinar (Kuwait)",
        "symbol": "د.ك"
    },
    "KYD": {
        "code": "KYD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Cayman Islands)",
        "symbol": "$"
    },
    "KZT": {
        "code": "KZT",
        "fractional_ratio": 100,
        "fractional_unit": "Tïın",
        "name": "Tenge (Kazakhstan)",
        "symbol": "₸"
    },
    "LAK": {
        "code": "LAK",
        "fractional_ratio": 100,
        "fractional_unit": "Att",
        "name": "Kip (Laos)",
        "symbol": "₭"
    },
    "LBP": {
        "code": "LBP",
        "fractional_ratio": 100,
        "fractional_unit": "Piastre",
        "name": "Pound (Lebanon)",
        "symbol": "ل.ل"
    },
    "LKR": {
        "code": "LKR",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Rupee (Sri Lanka)",
        "symbol": "Rs"
    },
    "LRD": {
        "code": "LRD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Liberia)",
        "symbol": "$"
    },
    "LSL": {
        "code": "LSL",
        "fractional_ratio": 100,
        "fractional_unit": "Sente",
        "name": "Loti (Lesotho)",
        "symbol": "L"
    },
    "LTL": {
        "code": "LTL",
        "fractional_ratio": 100,
        "fractional_unit": "Centas",
        "name": "Litas (Lithuania)",
        "symbol": "Lt"
    },
    "LVL": {
        "code": "LVL",
        "fractional_ratio": 100,
        "fractional_unit": "Santīms",
        "name": "Lat (Latvia)",
        "symbol": "Ls"
    },
    "LYD": {
        "code": "LYD",
        "fractional_ratio": 1000,
        "fractional_unit": "Dirham",
        "name": "Dinar (Libya)",
        "symbol": "ل.د"
    },
    "MAD": {
        "code": "MAD",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Dirham (Morocco)",
        "symbol": "د.م."
    },
    "MDL": {
        "code": "MDL",
        "fractional_ratio": 100,
        "fractional_unit": "Ban",
        "name": "Leu (Moldova)",
        "symbol": "L"
    },
    "MGA": {
        "code": "MGA",
        "fractional_ratio": 5,
        "fractional_unit": "Iraimbilanja",
        "name": "Ariary (Madagascar)",
        "symbol": "Ar"
    },
    "MKD": {
        "code": "MKD",
        "fractional_ratio": 100,
        "fractional_unit": "Deni",
        "name": "Denar (Macedonia)",
        "symbol": "ден"
    },
    "MMK": {
        "code": "MMK",
        "fractional_ratio": 100,
        "fractional_unit": "Pya",
        "name": "Kyat (Myanmar)",
        "symbol": "Ks"
    },
    "MNT": {
        "code": "MNT",
        "fractional_ratio": 100,
        "fractional_unit": "Möngö",
        "name": "Tughrik (Mongolia)",
        "symbol": "₮"
    },
    "MOP": {
        "code": "MOP",
        "fractional_ratio": 100,
        "fractional_unit": "Avo",
        "name": "Pataca (Macau)",
        "symbol": "P"
    },
    "MRO": {
        "code": "MRO",
        "fractional_ratio": 5,
        "fractional_unit": "Khoums",
        "name": "Ouguiya (Mauritania)",
        "symbol": "UM"
    },
    "MUR": {
        "code": "MUR",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Rupee (Mauritius)",
        "symbol": "₨"
    },
    "MVR": {
        "code": "MVR",
        "fractional_ratio": 100,
        "fractional_unit": "Laari",
        "name": "Rufiyaa (Maldives)",
        "symbol": ".ރ"
    },
    "MWK": {
        "code": "MWK",
        "fractional_ratio": 100,
        "fractional_unit": "Tambala",
        "name": "Kwacha (Malawi)",
        "symbol": "MK"
    },
    "MXN": {
        "code": "MXN",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Mexico)",
        "symbol": "$"
    },
    "MYR": {
        "code": "MYR",
        "fractional_ratio": 100,
        "fractional_unit": "Sen",
        "name": "Ringgit (Malaysia)",
        "symbol": "RM"
    },
    "MZN": {
        "code": "MZN",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Metical (Mozambique)",
        "symbol": "MT"
    },
    "NAD": {
        "code": "NAD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Namibia)",
        "symbol": "$"
    },
    "NGN": {
        "code": "NGN",
        "fractional_ratio": 100,
        "fractional_unit": "Kobo",
        "name": "Naira (Nigeria)",
        "symbol": "₦"
    },
    "NIO": {
        "code": "NIO",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Cordoba (Nicaragua)",
        "symbol": "C$"
    },
    "NOK": {
        "code": "NOK",
        "fractional_ratio": 100,
        "fractional_unit": "Øre",
        "name": "Krone (Norway)",
        "symbol": "kr"
    },
    "NPR": {
        "code": "NPR",
        "fractional_ratio": 100,
        "fractional_unit": "Paisa",
        "name": "Rupee (Nepal)",
        "symbol": "₨"
    },
    "NZD": {
        "code": "NZD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (New Zealand)",
        "symbol": "$"
    },
    "OMR": {
        "code": "OMR",
        "fractional_ratio": 1000,
        "fractional_unit": "Baisa",
        "name": "Rial (Oman)",
        "symbol": "ر.ع."
    },
    "PAB": {
        "code": "PAB",
        "fractional_ratio": 100,
        "fractional_unit": "Centésimo",
        "name": "Balboa (Panama)",
        "symbol": "B/."
    },
    "PEN": {
        "code": "PEN",
        "fractional_ratio": 100,
        "fractional_unit": "Céntimo",
        "name": "Sol (Peru Nuevo)",
        "symbol": "S/."
    },
    "PGK": {
        "code": "PGK",
        "fractional_ratio": 100,
        "fractional_unit": "Toea",
        "name": "Kina (Papua New Guinea)",
        "symbol": "K"
    },
    "PHP": {
        "code": "PHP",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Peso (Philippines)",
        "symbol": "₱"
    },
    "PKR": {
        "code": "PKR",
        "fractional_ratio": 100,
        "fractional_unit": "Paisa",
        "name": "Rupee (Pakistan)",
        "symbol": "₨"
    },
    "PLN": {
        "code": "PLN",
        "fractional_ratio": 100,
        "fractional_unit": "Grosz",
        "name": "Zloty (Poland)",
        "symbol": "zł"
    },
    "PYG": {
        "code": "PYG",
        "fractional_ratio": 100,
        "fractional_unit": "Céntimo",
        "name": "Guarani (Paraguay)",
        "symbol": "₲"
    },
    "QAR": {
        "code": "QAR",
        "fractional_ratio": 100,
        "fractional_unit": "Dirham",
        "name": "Riyal (Qatar)",
        "symbol": "ر.ق"
    },
    "RON": {
        "code": "RON",
        "fractional_ratio": 100,
        "fractional_unit": "Ban",
        "name": "New Leu (Romania)",
        "symbol": "L"
    },
    "RSD": {
        "code": "RSD",
        "fractional_ratio": 100,
        "fractional_unit": "Para",
        "name": "Dinar (Serbia)",
        "symbol": "РСД"
    },
    "RUB": {
        "code": "RUB",
        "fractional_ratio": 100,
        "fractional_unit": "Kopek",
        "name": "Ruble (Russia)",
        "symbol": "р."
    },
    "RWF": {
        "code": "RWF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Rwanda)",
        "symbol": "Fr"
    },
    "SAR": {
        "code": "SAR",
        "fractional_ratio": 100,
        "fractional_unit": "Halala",
        "name": "Riyal (Saudi Arabia)",
        "symbol": "ر.س"
    },
    "SBD": {
        "code": "SBD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Solomon Islands)",
        "symbol": "$"
    },
    "SCR": {
        "code": "SCR",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Rupee (Seychelles)",
        "symbol": "₨"
    },
    "SDG": {
        "code": "SDG",
        "fractional_ratio": 100,
        "fractional_unit": "Piastre",
        "name": "Pound (Sudan)",
        "symbol": "£"
    },
    "SEK": {
        "code": "SEK",
        "fractional_ratio": 100,
        "fractional_unit": "Öre",
        "name": "Krona (Sweden)",
        "symbol": "kr"
    },
    "SGD": {
        "code": "SGD",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Dollar (Singapore)",
        "symbol": ""
    },
    "SHP": {
        "code": "SHP",
        "fractional_ratio": 100,
        "fractional_unit": "Penny",
        "name": "Pound (Saint Helena)",
        "symbol": "£"
    },
    "SLL": {
        "code": "SLL",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Leone Leone (Sierra)",
        "symbol": "Le"
    },
    "SOS": {
        "code": "SOS",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Shilling (Somalia)",
        "symbol": "Sh"
    },
    "SPL": {
        "code": "SPL",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Luigino (Seborga)",
        "symbol": ""
    },
    "SRD": {
        "code": "SRD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Suriname)",
        "symbol": "$"
    },
    "SSP": {
        "code": "SSP",
        "fractional_ratio": 100,
        "fractional_unit": "Piaster",
        "name": "Pound (South Sudan)",
        "symbol": "£"
    },
    "STD": {
        "code": "STD",
        "fractional_ratio": 100,
        "fractional_unit": "Cêntimo",
        "name": "Dobra (Sao Tome)",
        "symbol": "Db"
    },
    "SVC": {
        "code": "SVC",
        "fractional_ratio": 100,
        "fractional_unit": "Centavo",
        "name": "Colon (El Salvador)",
        "symbol": "₡"
    },
    "SYP": {
        "code": "SYP",
        "fractional_ratio": 100,
        "fractional_unit": "Piastre",
        "name": "Pound (Syria)",
        "symbol": "£"
    },
    "SZL": {
        "code": "SZL",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Lilangeni (Swaziland)",
        "symbol": "L"
    },
    "THB": {
        "code": "THB",
        "fractional_ratio": 100,
        "fractional_unit": "Satang",
        "name": "Baht (Thailand)",
        "symbol": "฿"
    },
    "TJS": {
        "code": "TJS",
        "fractional_ratio": 100,
        "fractional_unit": "Diram",
        "name": "Somoni (Tajikistan)",
        "symbol": "ЅМ"
    },
    "TMT": {
        "code": "TMT",
        "fractional_ratio": 100,
        "fractional_unit": "Tennesi",
        "name": "Manat (Turkmenistan)",
        "symbol": "m"
    },
    "TND": {
        "code": "TND",
        "fractional_ratio": 1000,
        "fractional_unit": "Millime",
        "name": "Dinar (Tunisia)",
        "symbol": "د.ت"
    },
    "TOP": {
        "code": "TOP",
        "fractional_ratio": 100,
        "fractional_unit": "Seniti",
        "name": "Pa'anga (Tonga)",
        "symbol": "T$"
    },
    "TRY": {
        "code": "TRY",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Lira (Turkey)",
        "symbol": ""
    },
    "TTD": {
        "code": "TTD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (Trinidad and Tobago)",
        "symbol": "$"
    },
    "TVD": {
        "code": "TVD",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Dollar (Tuvalu)",
        "symbol": ""
    },
    "TWD": {
        "code": "TWD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "New Dollar (Taiwan)",
        "symbol": "$"
    },
    "TZS": {
        "code": "TZS",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Shilling (Tanzania)",
        "symbol": "Sh"
    },
    "UAH": {
        "code": "UAH",
        "fractional_ratio": 100,
        "fractional_unit": "Kopiyka",
        "name": "Hryvna (Ukraine)",
        "symbol": "₴"
    },
    "UGX": {
        "code": "UGX",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Shilling (Uganda)",
        "symbol": "Sh"
    },
    "USD": {
        "code": "USD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (United States)",
        "symbol": "$"
    },
    "UYU": {
        "code": "UYU",
        "fractional_ratio": 100,
        "fractional_unit": "Centésimo",
        "name": "Peso (Uruguay)",
        "symbol": "$"
    },
    "UZS": {
        "code": "UZS",
        "fractional_ratio": 100,
        "fractional_unit": "Tiyin",
        "name": "Som (Uzbekistan)",
        "symbol": "лв"
    },
    "VEF": {
        "code": "VEF",
        "fractional_ratio": 100,
        "fractional_unit": "Céntimo",
        "name": "Bolivar (Venezuela)",
        "symbol": "Bs F"
    },
    "VND": {
        "code": "VND",
        "fractional_ratio": 10,
        "fractional_unit": "Hào",
        "name": "Dong (Viet Nam)",
        "symbol": "₫"
    },
    "VUV": {
        "code": "VUV",
        "fractional_ratio": 1,
        "fractional_unit": "",
        "name": "Vatu (Vanuatu)",
        "symbol": "Vt"
    },
    "WST": {
        "code": "WST",
        "fractional_ratio": 100,
        "fractional_unit": "Sene",
        "name": "Tala (Samoa)",
        "symbol": "T"
    },
    "XAF": {
        "code": "XAF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Financial Cooperation in Central Africa)",
        "symbol": "Fr"
    },
    "XCD": {
        "code": "XCD",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Dollar (East Caribbean)",
        "symbol": "$"
    },
    "XDR": {
        "code": "XDR",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "International Monetary Fund (IMF)",
        "symbol": ""
    },
    "XOF": {
        "code": "XOF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (Financial Community of Africa)",
        "symbol": "Fr"
    },
    "XPF": {
        "code": "XPF",
        "fractional_ratio": 100,
        "fractional_unit": "Centime",
        "name": "Franc (French Pacific)",
        "symbol": "Fr"
    },
    "YER": {
        "code": "YER",
        "fractional_ratio": 100,
        "fractional_unit": "Fils",
        "name": "Rial (Yemen)",
        "symbol": "﷼"
    },
    "ZAR": {
        "code": "ZAR",
        "fractional_ratio": 100,
        "fractional_unit": "Cent",
        "name": "Rand (South Africa)",
        "symbol": "R"
    },
    "ZMK": {
        "code": "ZMK",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Kwacha (Zambia)",
        "symbol": ""
    },
    "ZWL": {
        "code": "ZWL",
        "fractional_ratio": 0,
        "fractional_unit": "",
        "name": "Dollar (Zimbabwe)",
        "symbol": ""
    }
}
